@@ -21,9 +21,21 @@ getModel.baseGmm <- function(object, ...)
   if(is(object$g, "formula"))
     {
     object$gradvf <- FALSE
-    dat <- getDat(object$g, object$x)
+    if (is.null(object$data))
+    	dat <- getDat(object$g, object$x)
+    else
+    	dat <- getDat(object$g, object$x, object$data)
+    
     if(is.null(object$weightsMatrix))
-      clname <- paste(class(object), ".", object$type, ".formula", sep = "")
+      {
+      if (object$vcov == "iid")
+      	{
+          clname <- "baseGmm.twoStep.formula"
+          object$type <- "Linear model with iid errors: Regular IV or 2SLS"
+         }
+      else	
+         clname <- paste(class(object), ".", object$type, ".formula", sep = "")
+      }
     else
       {
       clname <- "fixedW.formula"
